Package: shinycssloaders
Title: Add Loading Animations to a 'shiny' Output While It's
        Recalculating
Version: 1.1.0
Authors@R: c(
    person("Dean","Attali",email="daattali@gmail.com",role=c("aut","cre"),
        comment = c("Maintainer/developer of shinycssloaders since 2019", ORCID="0000-0002-5645-3493")),
    person("Andras","Sali",email="andras.sali@alphacruncher.hu",role=c("aut"),comment="Original creator of shinycssloaders package"),
    person("Luke","Hass",role=c("ctb","cph"),comment="Author of included CSS loader code")
    )
Description: When a 'Shiny' output (such as a plot, table, map, etc.) is recalculating, it remains 
    visible but gets greyed out. Using 'shinycssloaders', you can add a loading animation ("spinner")
    to outputs instead. By wrapping a 'Shiny' output in 'withSpinner()', a spinner will automatically
    appear while the output is recalculating. You can also manually show and hide the spinner, or add
    a full-page spinner to cover the entire page.
    See the demo online at <https://daattali.com/shiny/shinycssloaders-demo/>.
License: MIT + file LICENSE
URL: https://github.com/daattali/shinycssloaders,
        https://daattali.com/shiny/shinycssloaders-demo/
BugReports: https://github.com/daattali/shinycssloaders/issues
Depends: R (>= 3.1)
Imports: digest, glue, grDevices, htmltools (>= 0.3.5), shiny
Suggests: knitr, shinydisconnect, shinyjs
RoxygenNote: 7.2.3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2024-07-30 18:52:48 UTC; Dean
Author: Dean Attali [aut, cre] (Maintainer/developer of shinycssloaders since
    2019, <https://orcid.org/0000-0002-5645-3493>),
  Andras Sali [aut] (Original creator of shinycssloaders package),
  Luke Hass [ctb, cph] (Author of included CSS loader code)
Maintainer: Dean Attali <daattali@gmail.com>
Repository: CRAN
Date/Publication: 2024-07-30 22:30:02 UTC
